Use flash id to write image to flash

Update the item updater helper functions to take the flash id instead of
the version id since flash id is the name of the volumes/partitions.

The flash id was being persisted for the mmc layout with the name of
"partlabel". This is not needed anymore since the flash id is now being
passed by the service files.

The write functions/service files still use the version id to know where
the image files are located in /tmp/. They then set the value of flash
id (Path property) which is then used by the other functions such as
Delete and setting the u-boot environment variables.

Tested: Code update and Delete functions work on ubi and mmc.

Change-Id: I87c5b8ae2e24af30256dc3b436859835f14cda05
Signed-off-by: Adriana Kobylak <anoo@us.ibm.com>
diff --git a/item_updater_helper.hpp b/item_updater_helper.hpp
index de48df4..b328285 100644
--- a/item_updater_helper.hpp
+++ b/item_updater_helper.hpp
@@ -48,17 +48,17 @@
     /** @brief Do factory reset */
     void factoryReset();
 
     /** @brief Remove the image with the version id
      *
      * @param[in] versionId - The version id of the image
      */
-    void removeVersion(const std::string& versionId);
+    void removeVersion(const std::string& flashId);
 
     /** @brief Update version id in uboot env
      *
      * @param[in] versionId - The version id of the image
      */
-    void updateUbootVersionId(const std::string& versionId);
+    void updateUbootVersionId(const std::string& flashId);
 
     /** @brief Mirror Uboot to the alt uboot partition */
     void mirrorAlt();
@@ -48,17 +48,17 @@
     void factoryReset();
 
-    /** @brief Remove the image with the version id
+    /** @brief Remove the image with the flash id
      *
@@ -48,17 +48,17 @@
      *
-     * @param[in] versionId - The version id of the image
+     * @param[in] flashId - The flash id of the image
      */
@@ -48,17 +48,17 @@
 
-    /** @brief Update version id in uboot env
+    /** @brief Update flash id in uboot env
      *
@@ -48,17 +48,17 @@
      *
-     * @param[in] versionId - The version id of the image
+     * @param[in] flashId - The flash id of the image
      */